Description Usage Arguments Value
These functionals are:
the mean and standard deviation for each numeric or integer variable
Kendall's tau for each pair of numeric / integer variable;
the empirical proportion for each unique possibility of each variable of
type character or factor.
1 |
data |
the data frame of observations from which to construct the functionals. |
a list with
listfns: the constructed functionals
listinputs: their inputs
weightsfns: the weights that they should have so that each variable (categorical and continuous) has the influence
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.