generateSample_spatial: Help function to construct the matrix of the generated...

Description Usage

View source: R/mfm.R

Description

Help function to construct the matrix of the generated samples in the case where there is a spatial constraint.

Usage

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
generateSample_spatial(
  data,
  listfns,
  listinputs,
  coordX,
  coordY,
  minDistance,
  nDraws,
  sizeSample,
  progressBar
)

AlexisDerumigny/MFunctMatching documentation built on Dec. 31, 2020, 9:47 a.m.