generateSample_unconstrained: Help function to construct the matrix of the generated...

Description Usage

View source: R/mfm.R

Description

Help function to construct the matrix of the generated samples in the unconstrained case.

Usage

1
2
3
4
5
6
7
8
generateSample_unconstrained(
  data,
  listfns,
  listinputs,
  nDraws,
  sizeSample,
  progressBar
)

AlexisDerumigny/MFunctMatching documentation built on Dec. 31, 2020, 9:47 a.m.