mfm_standard: Standard version of the MFM algorithm

Description Usage Arguments Examples

View source: R/mfm_standard.R

Description

This function uses the MFM algorithm with predefined functionals, which are:

Usage

1
2
3
4
5
6
7
8
9
mfm_standard(
  data,
  coordX = NULL,
  coordY = NULL,
  minDistance = 0,
  nDraws,
  sizeSample,
  methodNormalization = "ecdf"
)

Arguments

data

the dataframe to use

coordX

the vector of X-coordinates

coordY

the vector of Y-coordinates

minDistance

minimum distance between two observations of the selected sample

nDraws

the number of random samples to generate from the population

sizeSample

the size of the sample

methodNormalization

the method used for normalization

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
df = data.frame(X1 = rnorm(2000), X2 = rnorm(2000),
                X3 = c(rep("A",500), rep("B", 500), rep("C", 1000)))
mfm_standard(data = df, nDraws = 500, sizeSample = 10,
             coordX = rnorm(2000), coordY = rnorm(2000))

# agricultural example
df = agridat::gartner.corn
mfm_standard(data = df[,c("mass", "moist", "elev")],
             nDraws = 500, sizeSample = 10,
             coordX = df$long, coordY = df$lat)

AlexisDerumigny/MFunctMatching documentation built on Dec. 31, 2020, 9:47 a.m.