Description Usage Arguments Value Examples
Find a sample representative of a given population by multifunctional matching
1 2 3 4 5 6 7 8 9 10 11 12 13 |
data |
the dataframe to use |
listfns |
the list of functionals |
listinputs |
the list of inputs, where each input is a vector of columns corresponding to each functional |
coordX |
the vector of X-coordinates |
coordY |
the vector of Y-coordinates |
minDistance |
minimum distance between two observations of the selected sample |
nDraws |
the number of random samples to generate from the population |
sizeSample |
the size of the sample |
methodNormalization |
the method used for normalization.
Can be |
weightsfns |
weights for each of the functionals. These weights can be used
to give more or less importance to some of the functionals.
It should be a vector of the same length as the |
progressBar |
|
a list with two elements
sample: the optimal set of (indices) of observations representing
best the population.
crit: the value of the MFM criteria.
1 2 3 4 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.