Description Usage Arguments Examples
View source: R/mfm_sampleSize.R
Choice of the optimal sample size for the MFM algorithm
1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 |
data |
the dataframe to use |
rangeSizeSample |
the list of the sample sizes to tested |
alpha |
the percentage of reduction of the criterion |
listfns |
list of functionals to be used. If |
listinputs |
list of inputs to the functionals.
Only used when |
coordX |
X coordinates of the points. Used for spatial data. |
coordY |
Y coordinates of the points. Used for spatial data. |
minDistance |
minimum distance between two observations of the selected sample |
nDraws |
number of draws to compute each MFM criterion. |
nReplications |
number of replications of the MFM criterion computation. |
methodNormalization |
the method used for normalization.
Can be |
weightsfns |
weights for each of the functionals. These weights can be used
to give more or less importance to some of the functionals.
It should be a vector of the same length as the |
progressBar |
|
1 2 3 4 5 6 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.